@@ -1,6 +1,9 @@
 # -*- coding: utf-8 -*-
 
-__version__ = '0.2.2'
+__version__ = '0.2.5'
+
+from sys import version_info as _vi
+py3 = _vi [0] > 2
 
 
 from cherrypy.lib import xmlrpcutil
@@ -21,3 +24,4 @@ cherrypy.config.update ({
     'engine.starter_stopper.on': True,
     'engine.task_manager.on': True
 })
+
