@@ -50,7 +50,7 @@ class EncryptedXmlrpcTool (cherrypy.Tool):
             message = unicode (e.args [0])
             code = to (int, e.args [1], 1)
         else:
-            message = '{}: {}'.format (type (e).__name__, unicode (e))
+            message = u'{}: {}'.format (type (e).__name__, unicode (e))
             code = 1
         body = _xmlrpclib.dumps (
             _xmlrpclib.Fault (code, message),
